Index: chrome/common/extensions/extension_messages.h |
diff --git a/chrome/common/extensions/extension_messages.h b/chrome/common/extensions/extension_messages.h |
index 32c24b3738b511701ac850a0f8820b17e954ca78..c9949b6a9213f91a2cae53f2dd0e6cf36c020fd3 100644 |
--- a/chrome/common/extensions/extension_messages.h |
+++ b/chrome/common/extensions/extension_messages.h |
@@ -30,11 +30,12 @@ |
IPC_ENUM_TRAITS(extensions::ViewType) |
-// Parameters structure for ExtensionHostMsg_AddAPIActionToActivityLog. |
-IPC_STRUCT_BEGIN(ExtensionHostMsg_APIAction_Params) |
+// Parameters structure for ExtensionHostMsg_AddAPIActionToActivityLog and |
+// ExtensionHostMsg_AddEventToActivityLog. |
+IPC_STRUCT_BEGIN(ExtensionHostMsg_APIActionOrEvent_Params) |
// API name. |
IPC_STRUCT_MEMBER(std::string, api_call) |
- |
+ |
palmer
2013/04/11 21:53:39
NIT: Spurious trailing spaces here?
felt
2013/04/12 02:07:21
Done.
|
// List of arguments. |
IPC_STRUCT_MEMBER(ListValue, arguments) |
@@ -603,7 +604,12 @@ IPC_MESSAGE_ROUTED1(ExtensionHostMsg_UpdateDraggableRegions, |
// Sent by the renderer to log an API action to the extension activity log. |
IPC_MESSAGE_CONTROL2(ExtensionHostMsg_AddAPIActionToActivityLog, |
std::string /* extension_id */, |
- ExtensionHostMsg_APIAction_Params) |
+ ExtensionHostMsg_APIActionOrEvent_Params) |
+ |
+// Sent by the renderer to log an event to the extension activity log. |
+IPC_MESSAGE_CONTROL2(ExtensionHostMsg_AddEventToActivityLog, |
+ std::string /* extension_id */, |
+ ExtensionHostMsg_APIActionOrEvent_Params) |
// Sent by the renderer to log a DOM action to the extension activity log. |
IPC_MESSAGE_CONTROL2(ExtensionHostMsg_AddDOMActionToActivityLog, |